@@ -126,6 +126,10 @@ extern "C" {
 #  define MRN_HAVE_HA_EXTRA_EXPORT
 #endif
 
+#if MYSQL_VERSION_ID >= 50617 && !defined(MRN_MARIADB_P)
+#  define MRN_HAVE_HA_EXTRA_SECONDARY_SORT_ROWID
+#endif
+
 #if MYSQL_VERSION_ID >= 50604 && !defined(MRN_MARIADB_P)
 #  define MRN_TIMESTAMP_USE_TIMEVAL
 #elif defined(MRN_MARIADB_P)
@@ -172,6 +176,10 @@ extern "C" {
 #  define MRN_HANDLER_START_BULK_INSERT_HAS_FLAGS
 #endif
 
+#if (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100010)
+#  define MRN_HAVE_TDC_LOCK_TABLE_SHARE
+#endif
+
 class ha_mroonga;
 
 /* structs */
@@ -256,6 +264,7 @@ private:
   grn_obj **grn_column_ranges;
   grn_obj **grn_index_tables;
   grn_obj **grn_index_columns;
+  bool grn_table_is_referenced;
 
   // buffers
   grn_obj  encoded_key_buffer;
@@ -727,6 +736,7 @@ private:
   int wrapper_open(const char *name, int mode, uint test_if_locked);
   int wrapper_open_indexes(const char *name);
   int storage_open(const char *name, int mode, uint test_if_locked);
+  void update_grn_table_is_referenced();
   int open_table(const char *name);
   int storage_open_columns(void);
   int storage_open_indexes(const char *name);
@@ -972,6 +982,8 @@ private:
   int wrapper_read_multi_range_next(KEY_MULTI_RANGE **found_range_p);
   int storage_read_multi_range_next(KEY_MULTI_RANGE **found_range_p);
 #endif // MRN_HANDLER_HAVE_MULTI_RANGE_READ
+  int generic_delete_all_rows(grn_obj *target_grn_table,
+                              const char *function_name);
   int wrapper_delete_all_rows();
   int storage_delete_all_rows();
 #ifdef MRN_HANDLER_HAVE_TRUNCATE
